@@ -94,6 +94,7 @@ needed.
 """
 
 from typing import Callable, Mapping, Sequence
+from urllib.parse import urljoin
 from oauthlib.oauth2 import BackendApplicationClient, OAuth2Error, \
     WebApplicationClient
 from requests import RequestException
@@ -104,6 +105,25 @@ from .client import SRFData
 __all__ = ['SRFDataOAuth']
 
 
+def make_urls(server_root):
+    """
+    Build keyword arguments for a non-standard server root.
+
+    Useful for testing:
+
+    .. code:: python
+
+        srf = SRFDataOAuth(client_id='TEST', client_secret='TEST,
+                           **make_urls('https://localhost:8443')
+
+    """
+    return {'root': urljoin(server_root, 'api'),
+            'redirect_uri': urljoin(server_root, 'oauth/callback'),
+            'auth_endpoint': urljoin(server_root, 'oauth/authorize'),
+            'token_endpoint': urljoin(server_root, 'oauth/token'),
+            'revoke_endpoint': urljoin(server_root, 'oauth/revoke')}
+
+
 class SRFDataOAuth(SRFData):
     """SRF Data client. Provides OAuth2-based access to the REST API."""
 
